__all__ = [
	'__author__', '__author_email__',
	'__copyright__', '__license__',
	'__summary__', '__title__',
	'__url__', '__version__',
	'__version_info__'
]

__title__ = 'google-music-utils'
__summary__ = 'A set of utility functionality for google-music and related projects.'
__url__ = 'https://github.com/thebigmunch/google-music-utils'

__version__ = '1.0.0'
__version_info__ = tuple(int(i) for i in __version__.split('.') if i.isdigit())

__author__ = 'thebigmunch'
__author_email__ = 'mail@thebigmunch.me'

__license__ = 'MIT'
__copyright__ = f'2018 {__author__} <{__author_email__}>'
